'''This is an example funciton for trial.
It prints all netsted list.'''
def print_lol(the_list,indent=False,level=1):
    for item in the_list:
        if isinstance(item,list):
            print_lol(item,indent,level+1)
        else:
            if(indent):
                for i in range(level):
                    print("\t",end='')
            print(item)
