from distutils.core import setup
setup(name='nestertud',
    version='2.0.1',
    py_modules=['nestertud'],
    author='friendtu',
    author_email='friendtu@gmail.com',
    url='http://www.headfirstlabs.com',
    description='A simple printer of nested lists',
    )